@@ -1,4 +1,4 @@
-package Dist::Zilla::Plugin::Author::Plicease::MakeMaker 2.31 {
+package Dist::Zilla::Plugin::Author::Plicease::MakeMaker 2.32 {
 
   use 5.014;
   use Moose;
@@ -150,42 +150,59 @@ package Dist::Zilla::Plugin::Author::Plicease::MakeMaker 2.31 {
 
     if($config || $build || $test || $clean)
     {
-      push @content, "sub MY::postamble {";
-      push @content, "  my \$postamble = '';";
+      push @content, "{ package MY;";
+      push @content, "  sub postamble {";
+      push @content, "    my \$postamble = '';";
       push @content, '';
       if($config)
       {
-        push @content, "  \$postamble .=";
-        push @content, "    \"config :: mymm_config\\n\" .";
-        push @content, "    \"mymm_config :\\n\" .";
-        push @content, "    \"\\t\\\$(FULLPERL) inc/mymm-config.pl\\n\\n\";";
+        push @content, "    \$postamble .=";
+        push @content, "      \"config :: _mm/config\\n\" .";
+        push @content, "      \"mymm-config _mm/config:\\n\" .";
+        push @content, "      \"\\t\\\$(FULLPERL) inc/mymm-config.pl\\n\" .";
+        push @content, "      \"\\t\\\$(NOECHO)\\\$(MKPATH) _mm\\n\" .";
+        push @content, "      \"\\t\\\$(NOECHO)\\\$(TOUCH) _mm/config\\n\\n\";";
         push @content, '';
       }
       if($build)
       {
-        push @content, "  \$postamble .=";
-        push @content, "    \"pure_all :: mymm_build\\n\" .";
-        push @content, "    \"mymm_build :\\n\" .";
-        push @content, "    \"\\t\\\$(FULLPERL) inc/mymm-build.pl\\n\\n\";";
+        push @content, "    \$postamble .=";
+        push @content, "      \"pure_all :: mymm-build\\n\" .";
+        push @content, "      \"mymm-build :@{[ $config ? ' _mm/config' : '' ]}\\n\" .";
+        push @content, "      \"\\t\\\$(FULLPERL) inc/mymm-build.pl\\n\\n\";";
         push @content, '';
       }
       if($test)
       {
-        push @content, "  \$postamble .=";
-        push @content, "    \"subdirs-test_dynamic subdirs-test_static subdirs-test :: mymm_test\\n\" .";
-        push @content, "    \"mymm_test :\\n\" .";
-        push @content, "    \"\\t\\\$(FULLPERL) inc/mymm-test.pl\\n\\n\";";
+        push @content, "    \$postamble .=";
+        push @content, "      \"subdirs-test_dynamic subdirs-test_static subdirs-test :: mymm-test\\n\" .";
+        push @content, "      \"mymm-test :\\n\" .";
+        push @content, "      \"\\t\\\$(FULLPERL) inc/mymm-test.pl\\n\\n\";";
         push @content, '';
       }
       if($clean)
       {
-        push @content, "  \$postamble .=";
-        push @content, "    \"clean :: mymm_clean\\n\" .";
-        push @content, "    \"mymm_clean : \\n\" . ";
-        push @content, "    \"\\t\\\$(FULLPERL) inc/mymm-clean.pl\\n\\n\";";
+        push @content, "    \$postamble .=";
+        push @content, "      \"clean :: mymm-clean\\n\" .";
+        push @content, "      \"mymm-clean :\\n\" .";
+        push @content, "      \"\\t\\\$(FULLPERL) inc/mymm-clean.pl\\n\" .";
+        push @content, "      \"\\t\\\$(RM_RF) _mm\\n\\n\";";
         push @content, '';
       }
-      push @content, "  \$postamble;";
+      push @content, "    \$postamble;";
+      push @content, "  }";
+
+      push @content, "  sub special_targets {";
+      push @content, "    my(\$self, \@therest) = \@_;";
+      push @content, "    my \$st = \$self->SUPER::special_targets(\@therest);";
+      push @content, "    \$st .= \"\\n.PHONY:";
+      $content[-1] .= " mymm-config" if $config;
+      $content[-1] .= " mymm-build" if $build;
+      $content[-1] .= " mymm-test" if $test;
+      $content[-1] .= " mymm-clean" if $clean;
+      $content[-1] .= "\\n\";";
+      push @content, "    \$st;";
+      push @content, "  }";
       push @content, "}";
     }
 
@@ -249,7 +266,7 @@ Dist::Zilla::Plugin::Author::Plicease::MakeMaker - munge the AUTHOR section
 
 =head1 VERSION
 
-version 2.31
+version 2.32
 
 =head1 SYNOPSIS
 
